==> blancoJsf-0.1.2-src.zip: blancoJsf/blanco/main/blanco/jsf/valueobject/BlancoJsfProcessStructure.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2009 IGA Tosiki
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.jsf.valueobject;

import java.util.List;

/**
 * blancoJsf ob`NX̊e킵܂B
 */
public class BlancoJsfProcessStructure {
    /**
     * JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * initialize, view, action ̂ꂩBl͓nĂȂBvOIɌ肵ĂB
     *
     * tB[h: [type]B
     */
    private String fType;

    /**
     * \bhB
     *
     * tB[h: [method]B
     */
    private String fMethod;

    /**
     * bZ[W`̐Lڂ܂B
     *
     * tB[h: [description]B
     */
    private String fDescription;

    /**
     * ʃtH[h̗LB
     *
     * tB[h: [forward]B
     * ftHg: [false]B
     */
    private boolean fForward = false;

    /**
     * beanꗗ̃XgB
     *
     * tB[h: [beanList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure>()]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure> fBeanList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure>();

    /**
     * SQL`IDꗗ̃XgB
     *
     * tB[h: [sqlList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure>();]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure> fSqlList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure>();;

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [type] ̒lݒ肵܂B
     *
     * tB[h̐: [initialize, view, action ̂ꂩBl͓nĂȂBvOIɌ肵ĂB]B
     *
     * @param argType tB[h[type]ɐݒ肷lB
     */
    public void setType(final String argType) {
        fType = argType;
    }

    /**
     * tB[h [type] ̒l擾܂B
     *
     * tB[h̐: [initialize, view, action ̂ꂩBl͓nĂȂBvOIɌ肵ĂB]B
     *
     * @return tB[h[type]擾lB
     */
    public String getType() {
        return fType;
    }

    /**
     * tB[h [method] ̒lݒ肵܂B
     *
     * tB[h̐: [\bhB]B
     *
     * @param argMethod tB[h[method]ɐݒ肷lB
     */
    public void setMethod(final String argMethod) {
        fMethod = argMethod;
    }

    /**
     * tB[h [method] ̒l擾܂B
     *
     * tB[h̐: [\bhB]B
     *
     * @return tB[h[method]擾lB
     */
    public String getMethod() {
        return fMethod;
    }

    /**
     * tB[h [description] ̒lݒ肵܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @param argDescription tB[h[description]ɐݒ肷lB
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h [description] ̒l擾܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @return tB[h[description]擾lB
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [forward] ̒lݒ肵܂B
     *
     * tB[h̐: [ʃtH[h̗LB]B
     *
     * @param argForward tB[h[forward]ɐݒ肷lB
     */
    public void setForward(final boolean argForward) {
        fForward = argForward;
    }

    /**
     * tB[h [forward] ̒l擾܂B
     *
     * tB[h̐: [ʃtH[h̗LB]B
     * ftHg: [false]B
     *
     * @return tB[h[forward]擾lB
     */
    public boolean getForward() {
        return fForward;
    }

    /**
     * tB[h [beanList] ̒lݒ肵܂B
     *
     * tB[h̐: [beanꗗ̃XgB]B
     *
     * @param argBeanList tB[h[beanList]ɐݒ肷lB
     */
    public void setBeanList(final List<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure> argBeanList) {
        fBeanList = argBeanList;
    }

    /**
     * tB[h [beanList] ̒l擾܂B
     *
     * tB[h̐: [beanꗗ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure>()]B
     *
     * @return tB[h[beanList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure> getBeanList() {
        return fBeanList;
    }

    /**
     * tB[h [sqlList] ̒lݒ肵܂B
     *
     * tB[h̐: [SQL`IDꗗ̃XgB]B
     *
     * @param argSqlList tB[h[sqlList]ɐݒ肷lB
     */
    public void setSqlList(final List<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure> argSqlList) {
        fSqlList = argSqlList;
    }

    /**
     * tB[h [sqlList] ̒l擾܂B
     *
     * tB[h̐: [SQL`IDꗗ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure>();]B
     *
     * @return tB[h[sqlList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure> getSqlList() {
        return fSqlList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.jsf.valueobject.BlancoJsfProcessStructure[");
        buf.append("name=" + fName);
        buf.append(",type=" + fType);
        buf.append(",method=" + fMethod);
        buf.append(",description=" + fDescription);
        buf.append(",forward=" + fForward);
        buf.append(",beanList=" + fBeanList);
        buf.append(",sqlList=" + fSqlList);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoJsf-0.1.4-src.zip: blancoJsf/blanco/main/blanco/jsf/valueobject/BlancoJsfProcessStructure.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2009 IGA Tosiki
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.jsf.valueobject;

import java.util.List;

/**
 * blancoJsf ob`NX̊e킵܂B
 */
public class BlancoJsfProcessStructure {
    /**
     * JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * initialize, view, action ̂ꂩBl͓nĂȂBvOIɌ肵ĂB
     *
     * tB[h: [type]B
     */
    private String fType;

    /**
     * \bhB
     *
     * tB[h: [method]B
     */
    private String fMethod;

    /**
     * bZ[W`̐Lڂ܂B
     *
     * tB[h: [description]B
     */
    private String fDescription;

    /**
     * ʃtH[h̗LB
     *
     * tB[h: [forward]B
     * ftHg: [false]B
     */
    private boolean fForward = false;

    /**
     * ActionEvent p̗LB
     *
     * tB[h: [actionEvent]B
     * ftHg: [false]B
     */
    private boolean fActionEvent = false;

    /**
     * beanꗗ̃XgB
     *
     * tB[h: [beanList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure>()]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure> fBeanList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure>();

    /**
     * SQL`IDꗗ̃XgB
     *
     * tB[h: [sqlList]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure>();]B
     */
    private List<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure> fSqlList = new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure>();;

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [JSF̊IDw肵܂BK{ڂłBʏ͉IDƂȂ܂B]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [type] ̒lݒ肵܂B
     *
     * tB[h̐: [initialize, view, action ̂ꂩBl͓nĂȂBvOIɌ肵ĂB]B
     *
     * @param argType tB[h[type]ɐݒ肷lB
     */
    public void setType(final String argType) {
        fType = argType;
    }

    /**
     * tB[h [type] ̒l擾܂B
     *
     * tB[h̐: [initialize, view, action ̂ꂩBl͓nĂȂBvOIɌ肵ĂB]B
     *
     * @return tB[h[type]擾lB
     */
    public String getType() {
        return fType;
    }

    /**
     * tB[h [method] ̒lݒ肵܂B
     *
     * tB[h̐: [\bhB]B
     *
     * @param argMethod tB[h[method]ɐݒ肷lB
     */
    public void setMethod(final String argMethod) {
        fMethod = argMethod;
    }

    /**
     * tB[h [method] ̒l擾܂B
     *
     * tB[h̐: [\bhB]B
     *
     * @return tB[h[method]擾lB
     */
    public String getMethod() {
        return fMethod;
    }

    /**
     * tB[h [description] ̒lݒ肵܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @param argDescription tB[h[description]ɐݒ肷lB
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h [description] ̒l擾܂B
     *
     * tB[h̐: [bZ[W`̐Lڂ܂B]B
     *
     * @return tB[h[description]擾lB
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [forward] ̒lݒ肵܂B
     *
     * tB[h̐: [ʃtH[h̗LB]B
     *
     * @param argForward tB[h[forward]ɐݒ肷lB
     */
    public void setForward(final boolean argForward) {
        fForward = argForward;
    }

    /**
     * tB[h [forward] ̒l擾܂B
     *
     * tB[h̐: [ʃtH[h̗LB]B
     * ftHg: [false]B
     *
     * @return tB[h[forward]擾lB
     */
    public boolean getForward() {
        return fForward;
    }

    /**
     * tB[h [actionEvent] ̒lݒ肵܂B
     *
     * tB[h̐: [ActionEvent p̗LB]B
     *
     * @param argActionEvent tB[h[actionEvent]ɐݒ肷lB
     */
    public void setActionEvent(final boolean argActionEvent) {
        fActionEvent = argActionEvent;
    }

    /**
     * tB[h [actionEvent] ̒l擾܂B
     *
     * tB[h̐: [ActionEvent p̗LB]B
     * ftHg: [false]B
     *
     * @return tB[h[actionEvent]擾lB
     */
    public boolean getActionEvent() {
        return fActionEvent;
    }

    /**
     * tB[h [beanList] ̒lݒ肵܂B
     *
     * tB[h̐: [beanꗗ̃XgB]B
     *
     * @param argBeanList tB[h[beanList]ɐݒ肷lB
     */
    public void setBeanList(final List<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure> argBeanList) {
        fBeanList = argBeanList;
    }

    /**
     * tB[h [beanList] ̒l擾܂B
     *
     * tB[h̐: [beanꗗ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure>()]B
     *
     * @return tB[h[beanList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfProcessBeanItemStructure> getBeanList() {
        return fBeanList;
    }

    /**
     * tB[h [sqlList] ̒lݒ肵܂B
     *
     * tB[h̐: [SQL`IDꗗ̃XgB]B
     *
     * @param argSqlList tB[h[sqlList]ɐݒ肷lB
     */
    public void setSqlList(final List<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure> argSqlList) {
        fSqlList = argSqlList;
    }

    /**
     * tB[h [sqlList] ̒l擾܂B
     *
     * tB[h̐: [SQL`IDꗗ̃XgB]B
     * ftHg: [new java.util.ArrayList<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure>();]B
     *
     * @return tB[h[sqlList]擾lB
     */
    public List<blanco.jsf.valueobject.BlancoJsfProcessSqlItemStructure> getSqlList() {
        return fSqlList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.jsf.valueobject.BlancoJsfProcessStructure[");
        buf.append("name=" + fName);
        buf.append(",type=" + fType);
        buf.append(",method=" + fMethod);
        buf.append(",description=" + fDescription);
        buf.append(",forward=" + fForward);
        buf.append(",actionEvent=" + fActionEvent);
        buf.append(",beanList=" + fBeanList);
        buf.append(",sqlList=" + fSqlList);
        buf.append("]");
        return buf.toString();
    }
}
